# -*- perl -*-

package Bundle::DBD::mysql;

$VERSION = '2.9002';

1;

__END__

=head1 NAME

Bundle::DBD::mysql - A bundle to install Perl drivers for mSQL or MySQL

=head1 SYNOPSIS

C<perl -MCPAN -e 'install Bundle::DBD::mysql'>

=head1 CONTENTS

DBI

Data::ShowTable

Mysql

DBD::mysql

=head1 DESCRIPTION

This bundle includes all that's needed to run both DBI drivers and
non-DBI drivers for mSQL or MySQL.

=cut
